-- ##########################################################################
-- #
-- #  Licensed Materials - Property of IBM
-- #  5698-MMI
-- #
-- #  (C) Copyright IBM Corp. 2002.  All Rights Reserved.
-- #
-- #  US Government Users Restricted Rights - Use, duplication or
-- #  disclosure restricted by GSA ADP Schedule Contract with
-- #  IBM Corp.
-- #
-- #   File Information: %W%
-- #   Revision: %I%
-- #   Date: %G% %U%
-- ############################################################################

-- All data is initially inserted into a temporary table that has
-- the same columns as the target table in the CDW.
-- That table is then inserted into the CDW table with a "where not exists"
-- clause. This insures that duplicate data is not inserted and an
-- error is not generated for trying to insert duplicate data.

declare global temporary table comptyp (
       CompTyp_Cd           CHAR(17) NOT NULL,
       CompTyp_Parent_Cd    CHAR(17),
       CompTyp_Nm           VARCHAR(120) NOT NULL,
       CompTyp_Strt_DtTm    TIMESTAMP NOT NULL,
       CompTyp_End_DtTm     TIMESTAMP NOT NULL
)
with replace on commit preserve rows not logged
;

--Insert all time values in UTC
insert into session.comptyp values ('HMI_HOST', NULL, 'WebSphere MQ Integrator Host', current timestamp - current timezone, '9999-01-01-12.00.00.000000');

insert into session.comptyp values ('HMI_QMGR', NULL, 'WebSphere MQ Queue Manager', current timestamp - current timezone, '9999-01-01-12.00.00.000000');

insert into session.comptyp values ('HMI_BROKER', NULL, 'WebSphere MQ Integrator Broker', current timestamp - current timezone, '9999-01-01-12.00.00.000000');

insert into session.comptyp values ('HMI_USR_NAME_SVR', NULL, 'WebSphere MQ Integrator Name Server', current timestamp - current timezone, '9999-01-01-12.00.00.000000');

insert into session.comptyp values ('HMI_CONFIG_MGR', NULL, 'WebSphere MQ Integrator Configuration Manager', current timestamp - current timezone, '9999-01-01-12.00.00.000000');

insert into session.comptyp values ('HMI_EXEC_GRP', NULL, 'WebSphere MQ Integrator Execution Group', current timestamp - current timezone, '9999-01-01-12.00.00.000000');

insert into session.comptyp values ('HMI_MSG_FLOW', NULL, 'WebSphere MQ Integrator Message Flow', current timestamp - current timezone, '9999-01-01-12.00.00.000000');

insert into session.comptyp values ('HMI_MONITOR_NODE', NULL, 'WebSphere MQ Integrator Monitor Node', current timestamp - current timezone, '9999-01-01-12.00.00.000000');

insert into twg.comptyp (CompTyp_Cd, CompTyp_Parent_Cd, CompTyp_Nm, CompTyp_Strt_DtTm, CompTyp_End_DtTm) 
select 
	s.CompTyp_Cd,
	s.CompTyp_Parent_Cd,
	s.CompTyp_Nm,
	s.CompTyp_Strt_DtTm,
	s.CompTyp_End_DtTm 
from session.comptyp s
where not exists (
  select 1 from
  twg.comptyp t where
  t.comptyp_cd = s.comptyp_cd
);

--
-- Insert Relationship Rules
--
declare global temporary table RelnRul (
		   CompTyp_Source_Cd    CHAR(17) NOT NULL,
       CompTyp_Target_Cd    CHAR(17) NOT NULL,
			 RelnTyp_Cd           VARCHAR(6) NOT NULL,
			 RelnRul_Strt_DtTm    TIMESTAMP NOT NULL,
       RelnRul_End_DtTm     TIMESTAMP NOT NULL
       
       
) 
with replace on commit preserve rows not logged
;

insert into session.RelnRul values('IP_HOST', 'HMI_QMGR', 'PCHILD', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.RelnRul values('IP_INTERFACE', 'HMI_QMGR', 'PCHILD', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.RelnRul values('HMI_HOST', 'HMI_QMGR', 'PCHILD', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.RelnRul values('HMI_QMGR', 'HMI_BROKER', 'PCHILD', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.RelnRul values('HMI_QMGR', 'HMI_USR_NAME_SVR', 'PCHILD', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.RelnRul values('HMI_QMGR', 'HMI_CONFIG_MGR', 'PCHILD', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.RelnRul values('HMI_BROKER', 'HMI_EXEC_GRP', 'PCHILD', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.RelnRul values('HMI_EXEC_GRP', 'HMI_MSG_FLOW', 'PCHILD', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.RelnRul values('HMI_MSG_FLOW', 'HMI_MONITOR_NODE', 'PCHILD', current timestamp - current timezone, '9999-01-01-12.00.00.000000');

insert into TWG.RelnRul (CompTyp_Source_Cd, CompTyp_Target_Cd, RelnTyp_Cd, RelnRul_Strt_DtTm, RelnRul_End_DtTm) 
select 
	s.CompTyp_Source_Cd,
	s.CompTyp_Target_Cd,
	s.RelnTyp_Cd,
	s.RelnRul_Strt_DtTm,
	s.RelnRul_End_DtTm  
from 
 session.RelnRul s
where not exists
( select 1 from
  TWG.RelnRul t
  where
  t.CompTyp_Source_Cd=s.CompTyp_Source_Cd and t.CompTyp_Target_Cd=s.CompTyp_Target_Cd)
;

--
-- Insert measurement source codes
--
declare global temporary table msrc (
  MSrc_Cd              CHAR(6) NOT NULL,
  MSrc_Parent_Cd       CHAR(6),
  MSrc_Nm              VARCHAR(120) NOT NULL
)
with replace on commit preserve rows not logged
;

insert into session.msrc values ('HMI', 'AMX', 'IBM Tivoli Monitoring for Business Integration 5.1.0 : WebSphere MQ Integrator');

insert into twg.msrc ( MSrc_Cd, MSrc_Parent_Cd, MSrc_Nm )
select 
	s.MSrc_Cd,
	s.MSrc_Parent_Cd,
	s.MSrc_Nm 
	from session.msrc s
where not exists (
  select 1 from
  twg.msrc t where
  t.msrc_Cd = s.msrc_Cd
);

--
-- Insert Measurement Types
--
declare global temporary table MsmtTyp (
			 MsmtTyp_ID           INTEGER,
       MUnit_Cd             CHAR(6) NOT NULL,
			 MSrc_Cd 	            CHAR(6) NOT NULL,
       MsmtTyp_Nm           VARCHAR(120) NOT NULL,
			 MsmtTyp_Ds           VARCHAR(254) 
) 
with replace on commit preserve rows not logged
;

insert into session.MsmtTyp values(0, 'PRC', 'HMI', 'Status_Up', 'Status up');
insert into session.MsmtTyp values(0, 'PRC', 'HMI', 'Status_Down', 'Status down');
insert into session.MsmtTyp values(0, 'PRC', 'HMI', 'Status_Limited', 'Status limited');
insert into session.MsmtTyp values(0, 'PRC', 'HMI', 'Status_Unknown', 'Status unknown');
insert into session.MsmtTyp values(0, 'QTY', 'HMI', 'Message_Count', 'Total number of messages');
insert into session.MsmtTyp values(0, 'B', 'HMI', 'Byte_Count', 'Total number of bytes');
insert into session.MsmtTyp values(0, 'Qps', 'HMI', 'Message_Rate', 'Number of messages per second');
insert into session.MsmtTyp values(0, 'Bps', 'HMI', 'Byte_Rate', 'Number of bytes per second');
insert into session.MsmtTyp values(0, 'MSec', 'HMI', 'Execution_Time', 'Execution time between monitor nodes');

insert into TWG.MsmtTyp ( MsmtTyp_ID, MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds)
select 
	s.MsmtTyp_ID,
	s.MUnit_Cd,
	s.MSrc_Cd,
	s.MsmtTyp_Nm,
	s.MsmtTyp_Ds  
from 
 session.MsmtTyp s
where not exists
( select 1 from
  TWG.MsmtTyp t
  where
  t.MsmtTyp_Nm=s.MsmtTyp_Nm )
;

--
-- Insert measurement groups
--
declare global temporary table mgrp (
  MGrp_Cd              CHAR(6) NOT NULL,
  MGrpTyp_Cd           CHAR(6) NOT NULL,
  MGrp_Parent_Cd       CHAR(6),
  MGrp_Nm              VARCHAR(120) NOT NULL
)
with replace on commit preserve rows not logged
;

insert into session.MGrp values ('HMI_ST','STATE', NULL, 'WebSphere MQ Integrator Status');

insert into twg.mgrp ( MGrp_Cd, MGrpTyp_Cd, MGrp_Parent_Cd, MGrp_Nm )
select 
	s.MGrp_Cd,
	s.MGrpTyp_Cd,
	s.MGrp_Parent_Cd,
	s.MGrp_Nm  
from session.mgrp s
where not exists (
  select 1 from
  twg.mgrp t where
  t.mgrp_Cd = s.mgrp_Cd and t.mgrptyp_Cd = s.mgrptyp_Cd
);


--
-- Insert Measurement Group Members
--
declare global temporary table MGrpMbr (
			 MGrp_Cd           CHAR(6) NOT NULL,
			 MGrpTyp_Cd        CHAR(6) NOT NULL,
			 MsmtTyp_ID        INTEGER
) 
with replace on commit preserve rows not logged
;


insert into session.MGrpMbr
select
	'MIN_E' as MGrp_Cd,
	'GROUP' as MGrpTyp_Cd,
	m.MsmtTyp_ID as MsmtTyp_ID
from
	twg.MsmtTyp m
where 
	 m.MsmtTyp_Nm in 
	('Message_Rate',
	'Byte_Rate',
	'Execution_Time');
	
insert into session.MGrpMbr
select
	'MAX_E' as MGrp_Cd,
	'GROUP' as MGrpTyp_Cd,
	m.MsmtTyp_ID as MsmtTyp_ID
from
	twg.MsmtTyp m
where 
	 m.MsmtTyp_Nm in 
	('Message_Rate',
	'Byte_Rate',
	'Execution_Time');

insert into session.MGrpMbr
select
	'AVG_E' as MGrp_Cd,
	'GROUP' as MGrpTyp_Cd,
	m.MsmtTyp_ID as MsmtTyp_ID
from
	twg.MsmtTyp m
where 
	 m.MsmtTyp_Nm in
	('Message_Rate',
	'Byte_Rate',
	'Status_Up', 
	'Status_Down',
	'Status_Limited',
	'Status_Unknown',
	'Execution_Time'
	);	
	
insert into session.MGrpMbr
select
	'TOT_E' as MGrp_Cd,
	'GROUP' as MGrpTyp_Cd,
	m.MsmtTyp_ID as MsmtTyp_ID
from
	twg.MsmtTyp m
where 
  m.MsmtTyp_Nm='Message_Count' or 
	m.MsmtTyp_Nm='Byte_Count'  ;
	
insert into session.MGrpMbr
select
	'STATE' as MGrp_Cd,
	'CATEG' as MGrpTyp_Cd,
	m.MsmtTyp_ID as MsmtTyp_ID
from
	twg.MsmtTyp m
where 
	 m.MsmtTyp_Nm in
	('Status_Up', 
	'Status_Down',
	'Status_Limited',
	'Status_Unknown'
	);
	
insert into session.MGrpMbr
select
	'HMI_ST' as MGrp_Cd,
	'STATE' as MGrpTyp_Cd,
	m.MsmtTyp_ID as MsmtTyp_ID
from
	twg.MsmtTyp m
where 
	 m.MsmtTyp_Nm in
	('Status_Up', 
	'Status_Down',
	'Status_Limited',
	'Status_Unknown'
	);	
	
insert into TWG.MGrpMbr ( MGrp_Cd, MGrpTyp_Cd, MsmtTyp_ID )
select 
	s.MGrp_Cd,
	s.MGrpTyp_Cd,
	s.MsmtTyp_ID  
from 
 session.MGrpMbr s
where not exists
( select 1 from
  TWG.MGrpMbr t
  where
  t.MGrp_Cd=s.MGrp_Cd and t.mgrptyp_Cd = s.mgrptyp_Cd and t.MsmtTyp_ID=s.MsmtTyp_ID  )
;
	
--
-- Insert Measurement Rules
--
declare global temporary table MsmtRul (
			 CompTyp_Cd           CHAR(17) NOT NULL,
			 MsmtTyp_ID           INTEGER
) 
with replace on commit preserve rows not logged
;


insert into session.MsmtRul
select
	'HMI_BROKER' as CompTyp_Cd,
	m.MsmtTyp_ID as MsmtTyp_ID
from
	twg.MsmtTyp m
where 
	 m.MsmtTyp_Nm in
	('Status_Up',
	'Status_Down',
	'Status_Limited',
	'Status_Unknown'
	 );
	
insert into session.MsmtRul
select
	'HMI_USR_NAME_SVR' as CompTyp_Cd,
	m.MsmtTyp_ID as MsmtTyp_ID
from
	twg.MsmtTyp m
where 
	 m.MsmtTyp_Nm in
	('Status_Up',
	'Status_Down',
	'Status_Unknown'
	);
	
insert into session.MsmtRul
select
	'HMI_CONFIG_MGR' as CompTyp_Cd,
	m.MsmtTyp_ID as MsmtTyp_ID
from
	twg.MsmtTyp m
where 
	 m.MsmtTyp_Nm in
	('Status_Up',
	'Status_Down',
	'Status_Unknown'
	);
	
insert into session.MsmtRul
select
	'HMI_MSG_FLOW' as CompTyp_Cd,
	m.MsmtTyp_ID as MsmtTyp_ID
from
	twg.MsmtTyp m
where 
	 m.MsmtTyp_Nm in
	('Status_Up',
	'Status_Down',
	'Status_Unknown'
	 );
	
insert into session.MsmtRul
select
	'HMI_MONITOR_NODE' as CompTyp_Cd,
	m.MsmtTyp_ID as MsmtTyp_ID
from
	twg.MsmtTyp m
where 
	 m.MsmtTyp_Nm in
	(	'Message_Count',
	'Byte_Count',
	'Message_Rate',
	'Byte_Rate',
	'Execution_Time'); 			
	
insert into TWG.MsmtRul ( CompTyp_Cd, MsmtTyp_ID )
select 
	s.CompTyp_Cd,
	s.MsmtTyp_ID  
from 
 session.MsmtRul s
where not exists
( select 1 from
  TWG.MsmtRul t
  where
  t.CompTyp_Cd=s.CompTyp_Cd and t.MsmtTyp_ID=s.MsmtTyp_ID  )
;
	

--
-- Insert Attribute Rules
--
declare global temporary table AttrRul (
  CompTyp_Cd           CHAR(17) NOT NULL,
  AttrTyp_Cd           CHAR(17) NOT NULL,
  AttrRul_Strt_DtTm    TIMESTAMP NOT NULL,
  AttrRul_End_DtTm     TIMESTAMP NOT NULL,
  AttrRul_Dom_Ind      CHAR NOT NULL
) 
with replace on commit preserve rows not logged
;

insert into session.AttrRul values('HMI_HOST','AMX_EID', current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
insert into session.AttrRul values('HMI_HOST','AMX_GMT_OFFSET', current timestamp - current timezone, '9999-01-01-12.00.00.000000', 'N');
--insert into session.AttrRul VALUES('HMI_QMGR', 'HMI_QMGRPLATFORM', CURRENT timestamp - CURRENT timezone, --'9999-01-01-12.00.00.000000', 'N');
--insert into session.AttrRul VALUES('HMI_QMGR', 'HMI_QMGRCMDLVL', CURRENT timestamp - CURRENT timezone, --'9999-01-01-12.00.00.000000', 'N');


insert into TWG.AttrRul ( CompTyp_Cd, AttrTyp_Cd, AttrRul_Strt_DtTm, AttrRul_End_DtTm, AttrRul_Dom_Ind)
select 
	s.CompTyp_Cd,
	s.AttrTyp_Cd,
	s.AttrRul_Strt_DtTm,
	s.AttrRul_End_DtTm,
	s.AttrRul_Dom_Ind  
from 
  session.AttrRul s
where not exists
( select 1 from
  TWG.AttrRul t,
  TWG.CompTyp c
  where
  t.AttrTyp_Cd=s.AttrTyp_Cd and c.CompTyp_Cd=s.CompTyp_Cd)
;

----------------------------------------------
-- Translation tables
----------------------------------------------

declare global temporary table HMI_RelnRul_Transl (
CompTyp_Source_Cd	varchar(17) not null,
CompTyp_Target_Cd	varchar(17) not null,
RelnTyp_cd		char(6) not null,
RelnRul_Strt_DtTm    	Timestamp not null,
RelnRul_End_DtTm        Timestamp not null
)
with replace on commit preserve rows not logged
;

insert into session.HMI_RelnRul_Transl values ('HMI_RemBROKER','HMI_RemEXEC_GRP', 'PCHILD', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.HMI_RelnRul_Transl values ('HMI_EXEC_GRP','HMI_RemEXEC_GRP', 'SAME', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.HMI_RelnRul_Transl values ('HMI_RemEXEC_GRP','HMI_RemMSG_FLOW', 'PCHILD', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.HMI_RelnRul_Transl values ('HMI_MSG_FLOW','HMI_RemMSG_FLOW', 'SAME', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.HMI_RelnRul_Transl values ('HMI_RemMSG_FLOW','HMI_RemMON_NODE', 'PCHILD', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.HMI_RelnRul_Transl values ('HMI_MONITOR_NODE','HMI_RemMON_NODE', 'SAME', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.HMI_RelnRul_Transl values ('HMI_QMGR','HMI_RemQMGR', 'PROXY', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.HMI_RelnRul_Transl values ('HMI_RemQMGR','HMI_RemBROKER', 'PCHILD', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.HMI_RelnRul_Transl values ('HMI_RemQMGR','HMI_RemNAME_SVR', 'PCHILD', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.HMI_RelnRul_Transl values ('HMI_BROKER','HMI_RemBROKER', 'SAME', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into session.HMI_RelnRul_Transl values ('HMI_USR_NAME_SVR','HMI_RemNAME_SVR', 'SAME', current timestamp - current timezone, '9999-01-01-12.00.00.000000');


insert into AMX.RelnRul_Transl ( CompTyp_Source_Cd, CompTyp_Target_Cd, RelnTyp_cd, RelnRul_Strt_DtTm, RelnRul_End_DtTm )
select 
t.CompTyp_Source_Cd,
t.CompTyp_Target_Cd,
t.RelnTyp_cd,
t.RelnRul_Strt_DtTm,
t.RelnRul_End_DtTm  
from 
 session.HMI_RelnRul_Transl t
where not exists
( select 1 from
  AMX.RelnRul_Transl m
  where
  t.comptyp_Source_Cd=m.comptyp_Source_Cd and t.comptyp_target_cd=m.comptyp_target_cd
  )
; 

--------------------------------------------------
-- Need to link the Resource to the compTyp_cd 
----------------------------------------------



declare global temporary table HMI_Resource_Transl (
resource		varchar(128) not null,
CompTyp_cd		varchar(17) not null
)
with replace on commit preserve rows not logged
;



insert into session.HMI_Resource_Transl values ('WebSphere_MQI_Queue_Manager','HMI_QMGR');
insert into session.HMI_Resource_Transl values ('WebSphere_MQI_Broker','HMI_BROKER');
insert into session.HMI_Resource_Transl values ('WebSphere_MQI_ConfigMgr','HMI_CONFIG_MGR');
insert into session.HMI_Resource_Transl values ('WebSphere_MQI_UserNameServer','HMI_USR_NAME_SVR');
insert into session.HMI_Resource_Transl values ('WebSphere_MQI_ExecutionGroup','HMI_EXEC_GRP');
insert into session.HMI_Resource_Transl values ('WebSphere_MQI_MessageFlow','HMI_MSG_FLOW');
insert into session.HMI_Resource_Transl values ('WebSphere_MQI_MonitorNode','HMI_MONITOR_NODE');
insert into session.HMI_Resource_Transl values ('WebSphere_MQI_Remote_UserNameServer','HMI_RemNAME_SVR');
insert into session.HMI_Resource_Transl values ('WebSphere_MQI_Remote_Queue_Manager','HMI_RemQMGR');
insert into session.HMI_Resource_Transl values ('WebSphere_MQI_Remote_Broker','HMI_RemBROKER');
insert into session.HMI_Resource_Transl values ('WebSphere_MQI_Remote_MessageFlow','HMI_RemMSG_FLOW');
insert into session.HMI_Resource_Transl values ('WebSphere_MQI_Remote_ExecutionGroup','HMI_RemEXEC_GRP');
insert into session.HMI_Resource_Transl values ('WebSphere_MQI_Remote_MonitorNode','HMI_RemMON_NODE');

insert into AMX.Resource_Transl ( resource, comptyp_cd )
select 
t.resource,
t.Comptyp_cd  
from 
 session.HMI_resource_Transl t
where not exists
( select 1 from
  AMX.Resource_Transl m
  where
  t.comptyp_Cd = m.comptyp_Cd 
  )
; 

--------------------------------------------------
-- Need to link the ITM Category to the AVA code 
----------------------------------------------

declare global temporary table HMI_Category_Transl (
category		varchar(120) not null,
MSrc_cd			char(3) not null
)
with replace on commit preserve rows not logged
;

insert into session.HMI_Category_Transl values ('WebSphere_MQI','HMI');


insert into AMX.Category_Transl ( category, Msrc_Cd )
select 
t.category,
t.Msrc_Cd  
from 
 session.HMI_Category_Transl t
where not exists
( select 1 from
  AMX.Category_Transl m
  where
  t.Msrc_Cd = m.Msrc_Cd 
  )
; 

--------------------------------------------------
-- Need a translation table if the property 
-- can have more than 17 characters 
-- Need to know which properties are key properties
-- Need to know which properties will be used for the Comp_Nm
--------------------------------------------------

declare global temporary table HMI_CompTyp_Transl (
Msrc_Cd			char(3) not null,
ITM_key_property	varchar(1096) not null,
Comptyp_cd		varchar(17) not null,
Comp_nm			varchar(254) not null
)
with replace on commit preserve rows not logged
;

insert into session.HMI_CompTyp_Transl values ('HMI','WebSphere_MQI_Queue_Manager.Queue_manager_name','HMI_QMGR','WebSphere_MQI_Queue_Manager.Queue_manager_name');
insert into session.HMI_CompTyp_Transl values ('HMI','WebSphere_MQI_ConfigMgr.Component_name','HMI_CONFIG_MGR','WebSphere_MQI_ConfigMgr.Component_name');
insert into session.HMI_CompTyp_Transl values ('HMI','WebSphere_MQI_UserNameServer.Component_name','HMI_USR_NAME_SVR','WebSphere_MQI_UserNameServer.Component_name');
insert into session.HMI_CompTyp_Transl values
('HMI','WebSphere_MQI_Remote_UserNameServer.Component_name','HMI_RemNAME_SVR','WebSphere_MQI_Remote_UserNameServer.Component_name');
insert into session.HMI_CompTyp_Transl values ('HMI','WebSphere_MQI_Broker.Component_name','HMI_BROKER','WebSphere_MQI_Broker.Component_name');
insert into session.HMI_CompTyp_Transl values ('HMI','WebSphere_MQI_ExecutionGroup.Execution_group_name', 'HMI_EXEC_GRP','WebSphere_MQI_ExecutionGroup.Execution_group_name');
insert into session.HMI_CompTyp_Transl values ('HMI','WebSphere_MQI_MessageFlow.Message_flow_name', 'HMI_MSG_FLOW','WebSphere_MQI_MessageFlow.Message_flow_name');
insert into session.HMI_CompTyp_Transl values ('HMI','WebSphere_MQI_MonitorNode.Monitor_node_name', 'HMI_MONITOR_NODE','WebSphere_MQI_MonitorNode.Monitor_node_name');
insert into session.HMI_CompTyp_Transl values
('HMI','WebSphere_MQI_Remote_Broker.Component_name','HMI_RemBROKER','WebSphere_MQI_Remote_Broker.Component_name');
insert into session.HMI_CompTyp_Transl values ('HMI','WebSphere_MQI_Remote_Queue_Manager.Queue_manager_name', 'HMI_RemQMGR','WebSphere_MQI_Remote_Queue_Manager.Queue_manager_name');
insert into session.HMI_CompTyp_Transl values ('HMI','WebSphere_MQI_Remote_ExecutionGroup.Execution_group_name', 'HMI_RemEXEC_GRP','WebSphere_MQI_Remote_ExecutionGroup.Execution_group_name');
insert into session.HMI_CompTyp_Transl values ('HMI','WebSphere_MQI_Remote_MessageFlow.Message_flow_name', 'HMI_RemMSG_FLOW','WebSphere_MQI_Remote_MessageFlow.Message_flow_name');
insert into session.HMI_CompTyp_Transl values ('HMI','WebSphere_MQI_Remote_MonitorNode.Monitor_node_name', 'HMI_RemMON_NODE','WebSphere_MQI_Remote_MonitorNode.Monitor_node_name');


insert into AMX.Comptyp_Transl ( Msrc_Cd, ITM_key_property, Comptyp_cd, Comp_format_nm )
select 
t.Msrc_Cd,
t.ITM_key_property,
t.Comptyp_cd,
t.Comp_nm  
from 
 session.HMI_Comptyp_Transl t
where not exists
( select 1 from
  AMX.Comptyp_Transl m
  where
  t.Msrc_Cd = m.Msrc_Cd and
  t.Comptyp_cd  = m.Comptyp_cd 
  )
; 


--------------------------------------------------
-- Need a translation table if the property 
-- can have more than 17 characters
----------------------------------------------
declare global temporary table HMI_AttrTyp_Transl (
Msrc_Cd			char(3) not null,
ITM_attr_property	varchar(120) not null,
AttrTyp_cd		varchar(17) not null
)
with replace on commit preserve rows not logged
;


insert into session.HMI_AttrTyp_Transl values ('HMI','WebSphere_MQI_Remote_Queue_Manager.LAST_IP_ADDRESS','LAST_IP_ADDRESS');
insert into session.HMI_AttrTyp_Transl values ('HMI','WebSphere_MQI_Remote_Queue_Manager.HMI_HOST','HMI_HOST');
--insert into session.HMI_AttrTyp_Transl VALUES 
--   ('HMI', 'WebSphere_MQ_Queue_Manager.Queue_manager_platform', 'HMI_QMGRPLATFORM');
--insert into session.HMI_AttrTyp_Transl VALUES 
--   ('HMI', 'WebSphere_MQ_Queue_Manager.Queue_manager_command_level', 'HMI_QMGRCMDLVL');
--INSERT INTO session.HMI_AttrTyp_Transl VALUES 
--   ('HMI', 'WebSphere_MQ_Remote_Queue_Manager.Queue_manager_platform', 'HMI_QMGRPLATFORM');
--INSERT INTO session.HMI_AttrTyp_Transl VALUES 
--   ('HMI', 'WebSphere_MQ_Remote_Queue_Manager.Queue_manager_command_level', 'HMI_QMGRCMDLVL');	 

insert into AMX.Attrtyp_Transl ( Msrc_Cd, ITM_attr_property, AttrTyp_Cd )
select 
t.Msrc_Cd,
t.ITM_attr_property,
t.AttrTyp_Cd  
from 
 session.HMI_Attrtyp_Transl t
where not exists
( select 1 from
  AMX.Attrtyp_Transl m
  where
  t.Msrc_Cd = m.Msrc_Cd and
  t.AttrTyp_cd  = m.AttrTyp_cd 
  )
; 

--Insert data into control table for pruning data from Msmt table.
--A date duration is decimal(8,0) and has the format yyyymmdd.

declare global temporary table prune_msmt_control(
       MSrc_Cd              CHAR(6) NOT NULL,
       TmSum_Cd             CHAR NOT NULL,
       PMsmtC_Age_In_Days   DECIMAL(8,0) NOT NULL
) 
with replace on commit preserve rows not logged
;

insert into session.Prune_Msmt_Control values (
  'HMI', 'H', 00000300
);
insert into session.Prune_Msmt_Control values (
  'HMI', 'D', 00000300
);
insert into session.Prune_Msmt_Control values (
  'HMI', 'W', 00010000
);
insert into session.Prune_Msmt_Control values (
  'HMI', 'M', 00010000
);

insert into TWG.Prune_Msmt_Control ( MSrc_Cd, TmSum_Cd, PMsmtC_Age_In_Days )
select 
	s.MSrc_Cd ,
	s.TmSum_Cd ,
	s.PMsmtC_Age_In_Days  
from 
 session.Prune_Msmt_Control s
where not exists
( select 1 from
  TWG.Prune_Msmt_Control t
  where
  t.MSrc_Cd = s.MSrc_Cd and
  t.TmSum_Cd = s.TmSum_Cd)
;

-- The TWG extract control table has entries for all movement of data
-- when the CDW database is the source and the target table is 
-- permanent (ie cannot be dropped and recreated if there is a failure)
declare global temporary table Extract_Control (
        ExtCtl_Source   	varchar(120) not null,
 	ExtCtl_Target   	varchar(120) not null,
 	ExtCtl_From_RawSeq      char(10) for bit data,
 	ExtCtl_To_RawSeq        char(10) for bit data,
 	ExtCtl_From_IntSeq      bigint,
 	ExtCtl_To_IntSeq        bigint,
 	ExtCtl_From_DtTm     	timestamp not null,
 	ExtCtl_To_DtTm       	timestamp not null
	)
with replace on commit preserve rows not logged
;


-- Extract control is not needed when moving data from staging to TWG.COMP or
-- TWG.COMPATTR because we use a where not exists when inserting data into
-- these tables.

-- Use extract control when moving data into the MART db.

insert into session.extract_control values (
    'TWG.MSMT' ,
    'HMI.STAGE_F_MN_HOUR' ,
    x'',
    x'',
    0,
    0,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.extract_control values (
    'TWG.MSMT' ,
    'HMI.STAGE_F_CS_HOUR' ,
    x'',
    x'',
    0,
    0,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

-----------------------------------------------
-- From TWG.COMP to the Mart Dimension tables
-----------------------------------------------

insert into session.extract_control values (
    'TWG.CUR_COMP',
    'HMI.STAGE_D_HMI_HOST' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.extract_control values (
    'TWG.CUR_COMP',
    'HMI.STAGE_D_CSW_METRIC' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.extract_control values (
    'HMI.STAGE_D_CSW_METRIC' ,
    'HMI.STAGE_D_CS_METRIC' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.extract_control values (
    'TWG.CUR_COMP',
    'HMI.STAGE_D_MNW_METRIC' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.extract_control values (
    'HMI.STAGE_D_MNW_METRIC' ,
    'HMI.STAGE_D_MN_METRIC' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.extract_control values (
    'TWG.CUR_COMP',
    'HMI.STAGE_D_MN' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into session.extract_control values (
    'TWG.CUR_COMP',
    'HMI.STAGE_D_CS' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);


-- insert the static data for the extract table 
-- if not exist already

insert into TWG.Extract_control (ExtCtl_Source, ExtCtl_Target, ExtCtl_From_RawSeq, ExtCtl_To_RawSeq, ExtCtl_From_IntSeq, ExtCtl_To_IntSeq, ExtCtl_From_DtTm, ExtCtl_To_DtTm)
select 
 m.ExtCtl_Source,
 m.ExtCtl_Target,
 m.ExtCtl_From_RawSeq,
 m.ExtCtl_To_RawSeq,
 m.ExtCtl_From_IntSeq,
 m.ExtCtl_To_IntSeq,
 m.ExtCtl_From_DtTm,
 m.ExtCtl_To_DtTm   
from 
 session.Extract_Control m
where not exists
( select 1 from
  TWG.Extract_Control t
  where
  t.ExtCtl_Source=m.ExtCtl_Source  and
  t.ExtCtl_Target=m.ExtCtl_Target
  )
; 
------------------------------------------
-- insert static data into the metrics dimension staging tables
------------------------------------------

declare global temporary table temp_min_exists (
 msmttyp_id	integer,
 min_exists     char(1)
)
with replace on commit preserve rows not logged 
; 
 
insert into session.temp_min_exists
select
 mb.msmttyp_id,
 'Y' as min_exists
from
 TWG.MgrpMbr mb 
where
 mb.mgrptyp_cd = 'GROUP' and
 mb.mgrp_cd='MIN_E'
;

declare global temporary table temp_max_exists (
 msmttyp_id	integer,
 max_exists     char(1)
)
with replace on commit preserve rows not logged 
; 
 
insert into session.temp_max_exists
select
 mb.msmttyp_id,
 'Y' as max_exists
from
 TWG.MgrpMbr mb 
where
 mb.mgrptyp_cd = 'GROUP' and
 mb.mgrp_cd='MAX_E'
;


declare global temporary table temp_avg_exists (
 msmttyp_id	integer,
 avg_exists     char(1)
)
with replace on commit preserve rows not logged 
; 
 
insert into session.temp_avg_exists
select
 mb.msmttyp_id,
 'Y' as avg_exists
from
 TWG.MgrpMbr mb 
where
 mb.mgrptyp_cd = 'GROUP' and
 mb.mgrp_cd='AVG_E'
;

declare global temporary table temp_tot_exists (
 msmttyp_id	integer,
 tot_exists     char(1)
)
with replace on commit preserve rows not logged 
; 
 
insert into session.temp_tot_exists
select
 mb.msmttyp_id,
 'Y' as tot_exists
from
 TWG.MgrpMbr mb 
where
 mb.mgrptyp_cd = 'GROUP' and
 mb.mgrp_cd='TOT_E'
;

delete from HMI.STAGE_D_MNW_METRIC;

insert into HMI.STAGE_D_MNW_METRIC
select
 mt.msmttyp_id as metric_id,
 'not used' as met_category,
 mt.msmttyp_nm as met_name,
 mt.msmttyp_ds as met_desc,
 mt.munit_cd as met_units ,
 value(min.min_exists,'N') as min_exists,
 value(max.max_exists,'N') as max_exists,
 value(avg.avg_exists,'N') as avg_exists,
 value(tot.tot_exists,'N') as total_exists,
 'HMI' as msrc_nm
from
 TWG.msmttyp mt left outer join session.temp_min_exists min
 on mt.msmttyp_id=min.msmttyp_id,
 TWG.msmttyp mt2 left outer join session.temp_max_exists max
 on mt2.msmttyp_id=max.msmttyp_id,
 TWG.msmttyp mt3 left outer join session.temp_avg_exists avg
 on mt3.msmttyp_id=avg.msmttyp_id,
 TWG.msmttyp mt4 left outer join session.temp_tot_exists tot
 on mt4.msmttyp_id=tot.msmttyp_id,
 TWG.MsmtRul mr,
 TWG.Mgrp mg1,
 TWG.MgrpMbr mb1
where
 mt.msmttyp_id = mr.msmttyp_id and 
 mr.comptyp_cd = 'HMI_MONITOR_NODE' and
 mt.MSrc_Cd = 'HMI' and
 mt.msmttyp_id = mt2.msmttyp_id and
 mt.msmttyp_id = mt3.msmttyp_id and
 mt.msmttyp_id = mt4.msmttyp_id and
 mt.msmttyp_id=mb1.msmttyp_id and
 mb1.mgrp_cd=mg1.mgrp_cd and
 mb1.mgrptyp_cd = 'GROUP'
group by
 mt.msmttyp_id, mt.msmttyp_nm, mt.msmttyp_ds, mt.munit_cd, 
 min_exists, avg_exists, tot_exists, max_exists
;

delete from HMI.STAGE_D_CSW_METRIC;

insert into HMI.STAGE_D_CSW_METRIC
select
 mt.msmttyp_id as metric_id,
 'not used' as met_category,
 mt.msmttyp_nm as met_name,
 mt.msmttyp_ds as met_desc,
 mt.munit_cd as met_units ,
 value(min.min_exists,'N') as min_exists,
 value(max.max_exists,'N') as max_exists,
 value(avg.avg_exists,'N') as avg_exists,
 value(tot.tot_exists,'N') as total_exists,
 'HMI' as msrc_nm
from
 TWG.msmttyp mt left outer join session.temp_min_exists min
 on mt.msmttyp_id=min.msmttyp_id,
 TWG.msmttyp mt2 left outer join session.temp_max_exists max
 on mt2.msmttyp_id=max.msmttyp_id,
 TWG.msmttyp mt3 left outer join session.temp_avg_exists avg
 on mt3.msmttyp_id=avg.msmttyp_id,
 TWG.msmttyp mt4 left outer join session.temp_tot_exists tot
 on mt4.msmttyp_id=tot.msmttyp_id,
 TWG.MsmtRul mr,
 TWG.Mgrp mg1,
 TWG.MgrpMbr mb1
where
 mt.msmttyp_id = mr.msmttyp_id and 
 mr.comptyp_cd in ( 'HMI_BROKER', 'HMI_CONFIG_MGR', 'HMI_USR_NAME_SVR', 'HMI_MSG_FLOW' ) and
 mt.MSrc_Cd = 'HMI' and
 mt.msmttyp_id = mt2.msmttyp_id and
 mt.msmttyp_id = mt3.msmttyp_id and
 mt.msmttyp_id = mt4.msmttyp_id and
 mt.msmttyp_id=mb1.msmttyp_id and
 mb1.mgrp_cd=mg1.mgrp_cd and
 mb1.mgrptyp_cd = 'GROUP'
group by
 mt.msmttyp_id, mt.msmttyp_nm, mt.msmttyp_ds, mt.munit_cd, 
 min_exists, avg_exists, tot_exists, max_exists
;

