-- ##########################################################################
-- #
-- #  Licensed Materials - Property of IBM
-- #  5698-MMI
-- #
-- #  (C) Copyright IBM Corp. 2002.  All Rights Reserved.
-- #
-- #  US Government Users Restricted Rights - Use, duplication or
-- #  disclosure restricted by GSA ADP Schedule Contract with
-- #  IBM Corp.
-- #
-- #   File Information: %W%
-- #   Revision: %I%
-- #   Date: %G% %U%
-- ############################################################################
---------------------------
-- HMI Host dimension
---------------------------

create table HMI.d_hmi_host(
 host_id     		integer not null,
 host_name    		varchar(254) not null,
 cust_nm		varchar(120) not null,
 centr_nm  		varchar(120) not null,
-- time_zone_name		varchar(120) not null,
      primary key (host_id)
);
  
-- msmttype (aka metric) dimension table
-- This is a static table populated by sql scripts vs DWC

create table hmi.d_mn_metric (
 Metric_ID            INTEGER NOT NULL,
 Met_Category         VARCHAR(10) NOT NULL,
 Met_Name             VARCHAR(120) NOT NULL,
 Met_Desc							VARCHAR(254) NOT NULL,
 Met_Units            CHAR(6) NOT NULL,
 MIN_Exists           CHARACTER NOT NULL,
 MAX_Exists           CHARACTER NOT NULL,
 AVG_Exists           CHARACTER NOT NULL,
 Total_Exists         CHARACTER NOT NULL,
 Msrc_Nm							VARCHAR(6),
       PRIMARY KEY (Metric_ID)
);

create table HMI.d_monitor_node (
 mon_node_id				integer not null,
 mon_node_name       varchar(254) not null,
 msg_flow_name       varchar(254) not null,
 exec_group_name		varchar(254),
 broker_name  			varchar(254),
 qmgr_name	  			varchar(254),
   primary key (mon_node_id)
);

create table hmi.d_cs_metric (
 Metric_ID            INTEGER NOT NULL,
 Met_Category         VARCHAR(10) NOT NULL,
 Met_Name             VARCHAR(120) NOT NULL,
 Met_Desc			    		VARCHAR(254) NOT NULL,
 Met_Units            CHAR(6) NOT NULL,
 MIN_Exists           CHARACTER NOT NULL,
 MAX_Exists           CHARACTER NOT NULL,
 AVG_Exists           CHARACTER NOT NULL,
 Total_Exists         CHARACTER NOT NULL,
 Msrc_Nm							VARCHAR(6),
       PRIMARY KEY (Metric_ID)
);


create table HMI.d_comp_status (
 comp_id				integer not null,
 comp_name       varchar(254) not null,
 comp_type			varchar(17) not null,
 qmgr_name       varchar(254) not null,
   primary key (comp_id)
);

-- FACT HOUR table

create table HMI.f_mn_hour (
  mon_node_id   integer not null,
  host_id		integer not null,
  metric_id integer not null,
  meas_hour timestamp not null,
  min_value float,
  max_value float,
  avg_value float,
	total_value float,
	sample_count integer,
	primary key (mon_node_id, host_id, metric_id , meas_hour )
);

create index hmi.f_mn_hour_indx1 on HMI.f_mn_hour(mon_node_id);
create index hmi.f_mn_hour_indx2 on HMI.f_mn_hour(host_id);
create index hmi.f_mn_hour_indx3 on HMI.f_mn_hour(metric_id);

-- FACT DAY table
-- The day, week, and month tables are populated by the aggregation UDP

create table hmi.f_mn_day (
  mon_node_id   integer not null,
   host_id		integer not null,
   metric_id integer not null,
   meas_date timestamp not null,
   min_value float,
   max_value float,
   avg_value float,
 	total_value float,
 	sample_count integer,
	primary key ( mon_node_id, host_id, metric_id , meas_date )
);

create index hmi.f_mn_day_indx1 on HMI.f_mn_day(mon_node_id);
create index hmi.f_mn_day_indx2 on HMI.f_mn_day(host_id);
create index hmi.f_mn_day_indx3 on HMI.f_mn_day(metric_id);

-- FACT WEEK table

create table hmi.f_mn_week 
(
  mon_node_id   integer not null,
   host_id		integer not null,
   metric_id integer not null,
   meas_date timestamp not null,
   min_value float,
   max_value float,
   avg_value float,
 	total_value float,
 	sample_count integer,
	primary key (mon_node_id, host_id, metric_id , meas_date )
);

create index hmi.f_mn_week_indx1 on HMI.f_mn_week(mon_node_id);
create index hmi.f_mn_week_indx2 on HMI.f_mn_week(host_id);
create index hmi.f_mn_week_indx3 on HMI.f_mn_week(metric_id);

-- FACT MONTH table

create table hmi.f_mn_month 
(
  mon_node_id   integer not null,
   host_id		integer not null,
   metric_id integer not null,
   meas_date timestamp not null,
   min_value float,
   max_value float,
   avg_value float,
 	total_value float,
 	sample_count integer,
	primary key (mon_node_id, host_id, metric_id , meas_date )
);

create index hmi.f_mn_month_indx1 on HMI.f_mn_month(mon_node_id);
create index hmi.f_mn_month_indx2 on HMI.f_mn_month(host_id);
create index hmi.f_mn_month_indx3 on HMI.f_mn_month(metric_id);

-- FACT HOUR table

create table HMI.f_cs_hour (
  comp_id   integer not null,
  host_id		integer not null,
  metric_id integer not null,
  meas_hour timestamp not null,
  min_value float,
  max_value float,
  avg_value float,
	total_value float,
	sample_count integer,
	primary key (comp_id, host_id, metric_id , meas_hour )
);

create index  hmi.f_cs_hour_indx1 on HMI.f_cs_hour(comp_id);
create index  hmi.f_cs_hour_indx2 on HMI.f_cs_hour(host_id);
create index hmi.f_cs_hour_indx3 on HMI.f_cs_hour(metric_id);

-- FACT DAY table
-- The day, week, and month tables are populated by the aggregation UDP

create table hmi.f_cs_day (
  comp_id   integer not null,
   host_id		integer not null,
   metric_id integer not null,
   meas_date timestamp not null,
   min_value float,
   max_value float,
   avg_value float,
 	total_value float,
 	sample_count integer,
	primary key (comp_id, host_id, metric_id , meas_date )
);

create index hmi.f_cs_day_indx1 on HMI.f_cs_day(comp_id);
create index hmi.f_cs_day_indx2 on HMI.f_cs_day(host_id);
create index hmi.f_cs_day_indx3 on HMI.f_cs_day(metric_id);

-- FACT WEEK table

create table hmi.f_cs_week 
(
  comp_id   integer not null,
   host_id		integer not null,
   metric_id integer not null,
   meas_date timestamp not null,
   min_value float,
   max_value float,
   avg_value float,
 	total_value float,
 	sample_count integer,
	primary key (comp_id, host_id, metric_id , meas_date )
);

create index hmi.f_cs_week_indx1 on HMI.f_cs_week(comp_id);
create index hmi.f_cs_week_indx2 on HMI.f_cs_week(host_id);
create index  hmi.f_cs_week_indx3 on HMI.f_cs_week(metric_id);


-- FACT MONTH table

create table hmi.f_cs_month 
(
  comp_id   integer not null,
   host_id		integer not null,
   metric_id integer not null,
   meas_date timestamp not null,
   min_value float,
   max_value float,
   avg_value float,
 	total_value float,
 	sample_count integer,
	primary key (comp_id, host_id, metric_id , meas_date )
);


create index  hmi.f_cs_month_indx1 on HMI.f_cs_month(comp_id);
create index  hmi.f_cs_month_indx2 on HMI.f_cs_month(host_id);
create index hmi.f_cs_month_indx3 on HMI.f_cs_month(metric_id);

-- pruning control for fact tables

create table hmi.prune_mart_control (
	Table_Name				varchar(120) not null,
	PMartC_Duration		decimal(8,0) not null
	);
	
CREATE TABLE hmi.PRUNE_MART_LOG ( 
        PMart_Run_DtTm     timestamp  not null, 
        Table_Name         Varchar(30),   
        PMartC_Duration    DECIMAL(8,0) NOT NULL,    
        Number_Pruned      Decimal(8,0) Not Null
);	
