#!/bin/sh
############################################################################
#
#  Licensed Materials - Property of IBM
#  Product ID = 5698-MMI
#
#  (C) Copyright IBM Corp. 2002.  All Rights Reserved.
#
#  US Government Users Restricted Rights - Use, duplication or
#  disclosure restricted by GSA ADP Schedule Contract with
#  IBM Corp.
#
#   File Information: %W%
#   Revision: %I%
#   Date: %G% %U%
############################################################################

############################################################################
# Command Line Args:
#	1 = the path and name of the TWH Application config file
#	2 = Application working directory or install base directory
#		$TWH_TOPDIR/apps/ava_code_for_app/vapp_version (look at install tree)
#
# Required Config File:
#       twh_app_install.cfg
#
# Installation Logs (Default names):
#       A log will be generated for this script called hmi_after.sh.log
#
# Required Env Vars:
#       None.
#
# Return Codes:
#	0 = Success
#	255 = Failure
#
# Interpreter Required:
#       NT/2000 = BASH
#       Unix    = SH (Bourne Shell)
#
# Message Types:
#       (I) - Informational
#       (W) - Warning
#       (F) - Fatal
#
# Install Steps Required Before this Script Executes:
#       6 - TWH Core tools and application components must be
#	      successfully installed
#
#
# Note - Caution needs to be taken for NT paths that have a space.  This
#        is a limitation that requires double quoting around all 
#	   variables that contain a path.  Testing should be done to ensure
#	   this script runs with a space in any of the paths that are used.
#########################################################################
#


###
echo "        ** Before Script Log **          "
echo ""
echo "****************************************"
echo "* Application Before Script Start point *"
echo "****************************************"
echo ""

# Pulls in the generic shared routines

# Set parms
echo "      Parm 1 = $1"; TWH_CONFIG_FILE="$1"; export TWH_CONFIG_FILE
echo "      Parm 2 = $2"; APP_WORK_DIR="$2"; export APP_WORK_DIR
echo ""

# TWH_TOPDIR needs to always be in the environment
if [ -z "$TWH_TOPDIR" ]; then
  echo "      (F) Could not locate Env var TWH_TOPDIR"
  exit 255
fi

# Execute startup driver for beforescript
. "$TWH_TOPDIR"/install/bin/twh_core_startup_after.sh
exec_startup_driver;

#####################################################
######## Add application code below here ONLY #######
#####################################################

#
set_hmi_program_vars()
{
HMI_MISC_DIR="$APP_WORK_DIR/misc"    
HMI_MART_DDL_DIR="$APP_WORK_DIR/mart/ddl"
tmp_sql_file="hmi_tmp_sql.sql"        # name of the temporary sql file

TRUE=1
FALSE=0

return 0;
}


###


# Find the first partname of the indexes
find_indschema()
{

  # Test a connection
  echo "      (I) Testing the DB connection"
  err_txt=`$DB2EXEC_LOG connect to "$TWH_DM_DB" user "$COPT_MART_DB2USER" using "$COPT_MART_DB2PASS" 2>&1 `
  if [ $? -ne 0 ]; then
    echo "      (F) Unable to connect to database ($TWH_DM_DB)."
    echo "          Error is:"
    echo "          $err_txt"
    echo "          Exiting..."
    exit 255
  fi

  echo "==> Finding the index schema for the HMI fact tables in the MART Database"
  
  sql_find_indschema="select indschema from syscat.indexes where tabname='F_MN_HOUR' and tabschema='HMI' and indname='F_MN_HOUR_INDX1';"
  echo "connect to $TWH_DM_DB user $COPT_MART_DB2USER using $COPT_MART_DB2PASS;" > "$TMPDIR/$tmp_sql_file";
  echo "$sql_find_indschema" >> "$TMPDIR/$tmp_sql_file"
  INDSCHEMA=`$DB2EXEC -xtf "$TMPDIR/$tmp_sql_file" |sed -e '1,8d' -e 's/ //g' `;
  
  ret=$?
  if [ $ret -gt 2 ] ; then
	  echo "      (F) Unable to find the schema for the index f_mn_hour_indx1"
          echo "          for the table HMI.F_MN_HOUR in the MART database:"
          echo "          Exiting..."
    exit 255
  fi

  perl "$HMI_MISC_DIR/index.pl" "$HMI_MISC_DIR/hmi_mart_drop_schema.sql.template" "$HMI_MART_DDL_DIR/hmi_mart_drop_schema.sql" "$INDSCHEMA"

  rm -f "$TMPDIR/$tmp_sql_file"

echo "      (I) Index schema found. Mart drop schema sql script created. Program will continue."
return 0;
}





############
### Main ###
############

echo "==> Processing main WPack routines"
echo ""

  set_hmi_program_vars;
  find_indschema;

echo ""
echo "      (I) Done processing main WPack routines"           


echo ""
echo "==> Completed executing application before script"
exit 0
